==> DhcpAdmin-1.0.tar.gz: DhcpAdmin/lib/librange.pl <==
#
# dhcpadmin
#
# Copyright (C) 2008 DesigNET, INC.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#

##########################################################
#
# range,rangemodѶͭ饤֥
#
# $RCSfile: librange.pl,v $
# $Revision: 1.6 $
# $Date: 2009/01/04 23:57:51 $
#
##########################################################

#
# ϰϤɤ߹
#
# []
#       arg0    ֥ͥå
#       arg1    󥸤ΰ
#       arg2    顼å
#
# [֤]
#       0       OK
#      -1       ƥ२顼
#

sub read_range
{
    my ($subnet, $rangelist, $errmsg) = @_;
    my @arr;
    my $line;

    # 󥸥եΥѥ
    my $range = $WORKDIR . "/" . $subnet . "/range";

    # ¸ߥå
    if (!-e $range) {
        # ¸ߤʤｪλ
        return 0;
    }

    # 󥸥եΥץ
    if (open(IN, "$range") == 0) {
        $$errmsg[$L_DISP] = $LANG{$ENV{$DISPLANG}}{'ERR_TMP_FILE1'} . "(" . $range .
                            ")";
        $$errmsg[$L_LOG] = $LANG{$LOGLANG}{'ERR_TMP_FILE1'} . "(" . $range . ")";
        return -1;
    }

    # ɤ߹˳Ǽ
    while (<IN>) {
        $line = $_;
        chomp($line);
        @arr = split(/,/, $line);
        $$rangelist{add2bin($arr[0])} = $line;
    }

    return 0;
}

1;

==> DhcpAdmin-1.01.tar.gz: DhcpAdmin/lib/librange.pl <==
#
# dhcpadmin
#
# Copyright (C) 2008 DesigNET, INC.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#

##########################################################
#
# range,rangemodѶͭ饤֥
#
# $RCSfile: librange.pl,v $
# $Revision: 1.7 $
# $Date: 2013/01/16 09:40:57 $
#
##########################################################

#
# ϰϤɤ߹
#
# []
#       arg0    ֥ͥå
#       arg1    󥸤ΰ
#       arg2    Shared-network
#       arg3    顼å
#
# [֤]
#       0       OK
#      -1       ƥ२顼
#

sub read_range
{
    my ($subnet, $rangelist, $shared, $errmsg) = @_;
    my @arr;
    my $line;

    # 󥸥եΥѥ
    my $range = $WORKDIR . "/" . $shared . "/" . $subnet . "/range";

    # ¸ߥå
    if (!-e $range) {
        # ¸ߤʤｪλ
        return 0;
    }

    # 󥸥եΥץ
    if (open(IN, "$range") == 0) {
        $$errmsg[$L_DISP] = $LANG{$ENV{$DISPLANG}}{'ERR_TMP_FILE1'} . "(" . $range .
                            ")";
        $$errmsg[$L_LOG] = $LANG{$LOGLANG}{'ERR_TMP_FILE1'} . "(" . $range . ")";
        return -1;
    }

    # ɤ߹˳Ǽ
    while (<IN>) {
        $line = $_;
        chomp($line);
        @arr = split(/,/, $line);
        $$rangelist{add2bin($arr[0])} = $line;
    }

    return 0;
}

1;
